<?php

// This file keeps track of upgrades to
// the certificateswall module
//
// Sometimes, changes between versions involve
// alterations to database structures and other
// major things that may break installations.
//
// The upgrade function in this file will attempt
// to perform all the necessary actions to upgrade
// your older installation to the current version.
//
// If there's something it cannot do itself, it
// will tell you what you need to do.
//
// The commands in here will all be database-neutral,
// using the functions defined in lib/ddllib.php

function xmldb_certificateswall_upgrade($oldversion=0) {

	global $CFG, $THEME, $DB;
	$dbman = $DB->get_manager();

	if(!class_exists('XMLDBTable')){
		class XMLDBTable extends xmldb_table{
		}
	}
	if(!class_exists('XMLDBField')){
		class XMLDBField extends xmldb_field{
			function setAttributes($type, $precision=null, $unsigned=null, $notnull=null, $sequence=null, $enum=null, $enumvalues=null, $default=null, $previous=null){
				return $this->set_attributes($type, $precision, $unsigned, $notnull, $sequence, $default, $previous);
			}
		}
	}
	if(!function_exists('add_field')){
		function add_field($table, $field){
			global $DB;
			$dbman = $DB->get_manager();
			if (!$dbman->field_exists($table, $field)) {
				$dbman->add_field($table, $field);
			}
			return true;
		}
	}

	$result = true;

	if ($result && $oldversion < 2012012801) {
		// Add new fields to certificate table
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificateidformat');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '2', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'emailothers');
		$result = $result && add_field($table, $field);

		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificatecustomformat');
		$field->setAttributes(XMLDB_TYPE_TEXT, 'small', null, null, null, null, null, null, 'certificateidformat');
		$result = $result && add_field($table, $field);
		
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('coursehours');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'certificatecustomformat');
		$result = $result && add_field($table, $field);
		
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificatetime');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'coursehours');
		$result = $result && add_field($table, $field);
		
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('lastnumber');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'certificatetime');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012012801, 'certificateswall');
	}
    
	if ($result && $oldversion < 2012020801) {
		// Add new fields to certificate table
	
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificateassigndate');
		$field->setAttributes(XMLDB_TYPE_TEXT, 'small', null, null, null, null, null, null, 'lastnumber');
		$result = $result && add_field($table, $field);
		
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificateenddate');
		$field->setAttributes(XMLDB_TYPE_TEXT, 'small', null, null, null, null, null, null, 'certificateassigndate');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012020801, 'certificateswall');
	}
    
	if ($result && $oldversion < 2012052902) {
		// Add new fields to certificate table
	
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('allowautoissue');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '2', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '1', 'certificateenddate');
		$result = $result && add_field($table, $field);
		
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('minimumgrade');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'allowautoissue');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012052902, 'certificateswall');
	}
	
	if ($result && $oldversion < 2012052903) {
		// Add new fields to certificate table
	
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('emailstudent');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '2', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'minimumgrade');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012052903, 'certificateswall');
	}
	if ($result && $oldversion < 2012052904) {
		// Add new fields to certificate table
	
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificateinfo');
		$field->setAttributes(XMLDB_TYPE_TEXT, 'medium', null, null, null, null, null, null, 'timemodified');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012052904, 'certificateswall');
	}
	if ($result && $oldversion < 2012101602) {
		// Add new fields to certificate table
	
		$table = new XMLDBTable('certificateswall');
		$field = new XMLDBField('certificatetemplate');
		$field->setAttributes(XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, null, '0', 'timemodified');
		$result = $result && add_field($table, $field);

		upgrade_mod_savepoint(true, 2012101602, 'certificateswall');
	}
	
	return $result;
}

?>