<?php
if (!defined('MOODLE_INTERNAL')) {
    die('Direct access to this script is forbidden.');    ///  It must be included from a Moodle page
}

require_once ($CFG->dirroot.'/course/moodleform_mod.php');
require_once($CFG->dirroot.'/mod/certificateswall/lib.php');

class mod_certificateswall_mod_form extends moodleform_mod {

    function definition() {
        global $CFG;

        $mform =& $this->_form;

        $mform->addElement('header', 'general', get_string('general', 'form'));

        $mform->addElement('text', 'name', get_string('certificatename', 'certificateswall'), array('size'=>'64'));
        if (!empty($CFG->formatstringstriptags)) {
            $mform->setType('name', PARAM_TEXT);
        } else {
            $mform->setType('name', PARAM_CLEAN);
        }
        $mform->addRule('name', null, 'required', null, 'client');

        $this->add_intro_editor(false, get_string('intro', 'certificateswall'));

        // Issue options
        $mform->addElement('header', 'issueoptions', get_string('issueoptions', 'certificateswall'));
        
        $ynoptions = array( 0 => get_string('no'), 1 => get_string('yes'));
        
        $mform->addElement('select', 'allowautoissue', get_string('allowautoissue', 'certificateswall'), $ynoptions);
        $mform->setDefault('allowautoissue', 1);
        $mform->addHelpButton('allowautoissue', 'allowautoissue', 'certificateswall');
        
        $mform->addElement('text', 'minimumgrade', get_string('minimumgrade', 'certificateswall'), array('size'=>'4', 'maxsize'=>'20'));
        $mform->setType('minimumgrade', PARAM_TEXT);
        $mform->addHelpButton('minimumgrade', 'minimumgrade', 'certificateswall');
        
        $mform->addElement('select', 'emailstudent', get_string('emailstudent', 'certificateswall'), $ynoptions);
        $mform->setDefault('emailstudent', 0);
        $mform->addHelpButton('emailstudent', 'emailstudent', 'certificateswall');
        
        $mform->addElement('select', 'emailteachers', get_string('emailteachers', 'certificateswall'), $ynoptions);
        $mform->setDefault('emailteachers', 0);
        $mform->addHelpButton('emailteachers', 'emailteachers', 'certificateswall');

        $mform->addElement('text', 'emailothers', get_string('emailothers', 'certificateswall'), array('size'=>'40', 'maxsize'=>'200'));
        $mform->setType('emailothers', PARAM_TEXT);
        $mform->addHelpButton('emailothers', 'emailothers', 'certificateswall');
        
        $codeformat = array( 0 => get_string('randomcode', 'certificateswall'), 1 => get_string('customcodeformat', 'certificateswall'));
        $mform->addElement('select', 'certificateidformat', get_string('certificateidformat', 'certificateswall'), $codeformat);
        $mform->setDefault('certificateidformat', $CFG->certificateswall_certificateidformat);
        $mform->addHelpButton('certificateidformat', 'certificateidformat', 'certificateswall');
        
        $mform->addElement('text', 'certificatecustomformat', get_string('certificatecustomformat', 'certificateswall'), array('size'=>'30', 'maxsize'=>'200'));
        $mform->setType('certificatecustomformat', PARAM_TEXT);
        $mform->setDefault('certificatecustomformat', $CFG->certificateswall_certificatecustomformat);
        $mform->addHelpButton('certificatecustomformat', 'certificatecustomformat', 'certificateswall');
        
        $mform->addElement('text', 'coursehours', get_string('coursehours', 'certificateswall'), array('size'=>'6', 'maxsize'=>'10'));
        $mform->setType('coursehours', PARAM_TEXT);
        $mform->addHelpButton('coursehours', 'coursehours', 'certificateswall');
        
        $mform->addElement('text', 'certificateassigndate', get_string('certificateassigndate', 'certificateswall'), array('size'=>'6', 'maxsize'=>'10'));
        $mform->setType('certificateassigndate', PARAM_TEXT);
        $mform->addHelpButton('certificateassigndate', 'certificateassigndate', 'certificateswall');
        
        $mform->addElement('text', 'certificateenddate', get_string('certificateenddate', 'certificateswall'), array('size'=>'6', 'maxsize'=>'10'));
        $mform->setType('certificateenddate', PARAM_TEXT);
        $mform->addHelpButton('certificateenddate', 'certificateenddate', 'certificateswall');
        
        $mform->addElement('text', 'certificatetime', get_string('certificatetime', 'certificateswall'), array('size'=>'6', 'maxsize'=>'10'));
        $mform->setType('certificatetime', PARAM_TEXT);
        $mform->addHelpButton('certificatetime', 'certificatetime', 'certificateswall');

        $tmpls=certificateswall_api_get_templates();
        if(isset($tmpls->response->templates)){
        	$templates = array();
        	$default='0';
        	foreach($tmpls->response->templates as $t){
        		$templates[$t->id]=$t->title;
        		if($t->default=='y') $default=$t->id;
        	}
        	$mform->addElement('select', 'certificatetemplate', get_string('certificatetemplate', 'certificateswall'), $templates);
        	$mform->setDefault('certificatetemplate', $default);
        	$mform->addHelpButton('certificatetemplate', 'certificatetemplate', 'certificateswall');
        }

        $this->standard_coursemodule_elements();

        $this->add_action_buttons();

    }
}